summaryrefslogtreecommitdiff
path: root/gcc/rtl.h
diff options
context:
space:
mode:
authorrsandifo <rsandifo@138bc75d-0d04-0410-961f-82ee72b054a4>2006-03-03 09:11:58 +0000
committerrsandifo <rsandifo@138bc75d-0d04-0410-961f-82ee72b054a4>2006-03-03 09:11:58 +0000
commit6617cbc1eb60bc02c4fcf25ceaf07ccad481528e (patch)
tree735d1313d25f4094319b64fffac6f6b86aaed7f1 /gcc/rtl.h
parentcb21f4069f1cc5a093610a24859e93889574f99e (diff)
downloadgcc-6617cbc1eb60bc02c4fcf25ceaf07ccad481528e.tar.gz
* doc/tm.texi: Refer to SYMBOL_REF_HAS_BLOCK_INFO_P instead of
SYMBOL_REF_IN_BLOCK_P. * doc/rtl.texi: Likewise. Refer to SYMBOL_FLAG_HAS_BLOCK_INFO instead of SYMBOL_FLAG_IN_BLOCK. * gengtype.c (adjust_field_rtx_def): Use SYMBOL_REF_HAS_BLOCK_INFO_P instead of SYMBOL_REF_IN_BLOCK_P. * explow.c (use_anchored_address): Likewise. * rtl.c (rtx_size): Likewise. * varasm.c (create_block_symbol): Set SYMBOL_FLAG_HAS_BLOCK_INFO instead of SYMBOL_FLAG_IN_BLOCK. (make_decl_rtl): Use SYMBOL_REF_HAS_BLOCK_INFO_P instead of SYMBOL_REF_IN_BLOCK_P. (assemble_variable): Likewise. (output_constant_def_contents): Likewise. (output_constant_pool): Likewise. (default_encode_section_info): Preserve SYMBOL_FLAG_HAS_BLOCK_INFO instead of SYMBOL_FLAG_IN_BLOCK. * rtl.h (block_symbol): Refer to SYMBOL_REF_HAS_BLOCK_INFO_P instead of SYMBOL_REF_IN_BLOCK_P. (SYMBOL_REF_BLOCK): Likewise. (SYMBOL_REF_OFFSET): Likewise. (BLOCK_SYMBOL_CHECK): Use SYMBOL_REF_HAS_BLOCK_INFO_P instead of SYMBOL_REF_IN_BLOCK_P. (SYMBOL_FLAG_IN_BLOCK): Replace with... (SYMBOL_FLAG_HAS_BLOCK_INFO): ...this. (SYMBOL_REF_IN_BLOCK_P): Replace with... (SYMBOL_REF_HAS_BLOCK_INFO_P): ...this. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@111675 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/rtl.h')
-rw-r--r--gcc/rtl.h28
1 files changed, 15 insertions, 13 deletions
diff --git a/gcc/rtl.h b/gcc/rtl.h
index 236c8a13640..409734d4b88 100644
--- a/gcc/rtl.h
+++ b/gcc/rtl.h
@@ -178,7 +178,7 @@ typedef union rtunion_def rtunion;
/* This structure remembers the position of a SYMBOL_REF within an
object_block structure. A SYMBOL_REF only provides this information
- if SYMBOL_REF_IN_BLOCK_P is true. */
+ if SYMBOL_REF_HAS_BLOCK_INFO_P is true. */
struct block_symbol GTY(()) {
/* The usual SYMBOL_REF fields. */
rtunion GTY ((skip)) fld[3];
@@ -212,7 +212,7 @@ struct object_block GTY(())
order of increasing offset and the following conditions will
hold for each element X:
- SYMBOL_REF_IN_BLOCK_P (X)
+ SYMBOL_REF_HAS_BLOCK_INFO_P (X)
!SYMBOL_REF_ANCHOR_P (X)
SYMBOL_REF_BLOCK (X) == [address of this structure]
SYMBOL_REF_BLOCK_OFFSET (X) >= 0. */
@@ -222,7 +222,7 @@ struct object_block GTY(())
in order of increasing offset, and then increasing TLS model.
The following conditions will hold for each element X in this vector:
- SYMBOL_REF_IN_BLOCK_P (X)
+ SYMBOL_REF_HAS_BLOCK_INFO_P (X)
SYMBOL_REF_ANCHOR_P (X)
SYMBOL_REF_BLOCK (X) == [address of this structure]
SYMBOL_REF_BLOCK_OFFSET (X) >= 0. */
@@ -529,7 +529,7 @@ struct rtvec_def GTY(()) {
#define BLOCK_SYMBOL_CHECK(RTX) __extension__ \
({ rtx const _symbol = (RTX); \
unsigned int flags = RTL_CHECKC1 (_symbol, 1, SYMBOL_REF).rt_int; \
- if ((flags & SYMBOL_FLAG_IN_BLOCK) == 0) \
+ if ((flags & SYMBOL_FLAG_HAS_BLOCK_INFO) == 0) \
rtl_check_failed_block_symbol (__FILE__, __LINE__, \
__FUNCTION__); \
&_symbol->u.block_sym; })
@@ -1318,11 +1318,11 @@ do { \
#define SYMBOL_REF_EXTERNAL_P(RTX) \
((SYMBOL_REF_FLAGS (RTX) & SYMBOL_FLAG_EXTERNAL) != 0)
/* Set if this symbol has a block_symbol structure associated with it. */
-#define SYMBOL_FLAG_IN_BLOCK (1 << 7)
-#define SYMBOL_REF_IN_BLOCK_P(RTX) \
- ((SYMBOL_REF_FLAGS (RTX) & SYMBOL_FLAG_IN_BLOCK) != 0)
+#define SYMBOL_FLAG_HAS_BLOCK_INFO (1 << 7)
+#define SYMBOL_REF_HAS_BLOCK_INFO_P(RTX) \
+ ((SYMBOL_REF_FLAGS (RTX) & SYMBOL_FLAG_HAS_BLOCK_INFO) != 0)
/* Set if this symbol is a section anchor. SYMBOL_REF_ANCHOR_P implies
- SYMBOL_REF_IN_BLOCK_P. */
+ SYMBOL_REF_HAS_BLOCK_INFO_P. */
#define SYMBOL_FLAG_ANCHOR (1 << 8)
#define SYMBOL_REF_ANCHOR_P(RTX) \
((SYMBOL_REF_FLAGS (RTX) & SYMBOL_FLAG_ANCHOR) != 0)
@@ -1331,13 +1331,15 @@ do { \
#define SYMBOL_FLAG_MACH_DEP_SHIFT 9
#define SYMBOL_FLAG_MACH_DEP (1 << SYMBOL_FLAG_MACH_DEP_SHIFT)
-/* The block to which the given SYMBOL_REF belongs, or NULL if none.
- Only valid if SYMBOL_REF_IN_BLOCK_P (RTX). */
+/* If SYMBOL_REF_HAS_BLOCK_INFO_P (RTX), this is the object_block
+ structure to which the symbol belongs, or NULL if it has not been
+ assigned a block. */
#define SYMBOL_REF_BLOCK(RTX) (BLOCK_SYMBOL_CHECK (RTX)->block)
-/* The byte offset of the given SYMBOL_REF from the start of its block,
- or a negative value if the symbol has not yet been assigned a position.
- Only valid if SYMBOL_REF_IN_BLOCK_P (RTX). */
+/* If SYMBOL_REF_HAS_BLOCK_INFO_P (RTX), this is the offset of RTX from
+ the first object in SYMBOL_REF_BLOCK (RTX). The value is negative if
+ RTX has not yet been assigned to a block, or it has not been given an
+ offset within that block. */
#define SYMBOL_REF_BLOCK_OFFSET(RTX) (BLOCK_SYMBOL_CHECK (RTX)->offset)
/* Define a macro to look for REG_INC notes,